import { ApiCredentials, RegionType } from '@tencent-serverless-framework/common';
import { ApigwCreateOrUpdateServiceInputs, ApigwDeployInputs, ApigwDeployOutputs, ApigwRemoveInputs, ApigwUsagePlan } from './interface';
import { Client } from 'tencentcloud-sdk-nodejs/tencentcloud/services/apigateway/v20180808/apigateway_client';
import { UsagePlan } from './usage-plan';
import { Trigger } from './trigger';
import { Api } from './api';
import { CustomDomain } from './custom-domain';
export declare const t: import("i18next").TFunction;
/** 腾讯云 API 网关 for serverless component */
export declare class Apigw {
    /** 认证信息 */
    credentials: ApiCredentials;
    /** API 网关客户端 */
    client: Client;
    /** 区域信息 */
    region: RegionType;
    /** 用量计划子模块 */
    usagePlan: UsagePlan;
    /** 触发器子模块 */
    trigger: Trigger;
    /** API (Endpoint )子模块 */
    api: Api;
    /** 自定义域名子模块 */
    customDomain: CustomDomain;
    /**
     * 构造函数
     *
     * @param credentials 认证信息
     * @param region 地域信息
     */
    constructor(credentials: ApiCredentials, region?: RegionType);
    /**
     * 创建或更新 API 网关服务
     *
     * @param serviceConf API 网关创建或更新服务输入
     * @returns 创建成功后返回的信息
     */
    createOrUpdateService(serviceConf: ApigwCreateOrUpdateServiceInputs): Promise<{
        serviceName: string;
        serviceId: string | undefined;
        subDomain: string | string[] | undefined;
        serviceCreated: boolean;
        usagePlan: ApigwUsagePlan | undefined;
    }>;
    /**
     * 部署 API 网关
     *
     * @param inputs 部署 API 网关输入
     * @returns 部署后的输出
     */
    deploy(inputs: ApigwDeployInputs): Promise<ApigwDeployOutputs>;
    /**
     * 移除 API 网关
     *
     * @param inputs 移除 API 网关参数
     */
    remove(inputs: ApigwRemoveInputs): Promise<void>;
}
